import { Module, Script } from './nodes';
export interface FormatOptions {
    indent?: {
        style: string;
        base: number;
        adjustMultilineComment: boolean;
    };
    newline?: '\n';
    space?: ' ';
    json?: boolean;
    renumber?: boolean;
    hexadecimal?: boolean;
    quotes?: 'single' | 'double';
    escapeless?: boolean;
    compact?: boolean;
    parentheses?: boolean;
    semicolons?: boolean;
    safeConcatenation?: boolean;
    preserveBlankLines?: boolean;
}
export interface MozillaOptions {
    comprehensionExpressionStartsWithAssignment: false;
    starlessGenerator: false;
}
export interface GenerateOptions {
    comment?: boolean;
    file?: string;
    format?: FormatOptions;
    moz?: MozillaOptions;
    sourceContent?: string;
    sourceMap?: null;
    sourceMapRoot?: null;
    sourceMapWithCode?: false;
    directive?: false;
    raw?: true;
    verbatim?: string | null;
    sourceCode?: null;
}
/**
 * Generates the code corresponding to the tree.
 * The return format depends upon whether the sourceMapWithCode option is defined.
 * @param program
 * @param options
 * @returns
 */
export declare function generate(program: Module | Script, options?: GenerateOptions): string | {
    code: string;
    map: {
        setSourceContent: (sourceMap: string, sourceContent: string) => void;
    };
};
export declare const escodegen: {
    generate: typeof generate;
    Precedence: GenerateOptions;
    FORMAT_MINIFY: {
        indent: {
            style: string;
            base: number;
        };
        renumber: boolean;
        hexadecimal: boolean;
        quotes: string;
        escapeless: boolean;
        compact: boolean;
        parentheses: boolean;
        semicolons: boolean;
    };
    FORMAT_DEFAULT: FormatOptions;
};
