import { ParseDelegate, ParseOptions } from './esprima';
import * as JSXNode from './jsx-nodes';
import * as Node from './nodes';
import { Marker, Parser } from './parser';
import { RawToken } from './token';
interface MetaJSXElement {
    node: Marker;
    opening: JSXNode.JSXOpeningElement;
    closing: JSXNode.JSXClosingElement | null;
    children: JSXNode.JSXChild[];
}
export declare class JSXParser extends Parser {
    constructor(code: string, options: ParseOptions, delegate: ParseDelegate);
    parsePrimaryExpression(): Node.Expression;
    startJSX(): void;
    finishJSX(): void;
    reenterJSX(): void;
    createJSXNode(): Marker;
    createJSXChildNode(): Marker;
    scanXHTMLEntity(quote: string): string;
    lexJSX(): RawToken;
    nextJSXToken(): RawToken;
    nextJSXText(): RawToken;
    peekJSXToken(): RawToken;
    expectJSX(value: "{" | "}" | "<" | ">" | ":" | "." | "/" | "..." | "="): void | never;
    matchJSX(value: "{" | "}" | "<" | ">" | ":" | "." | "/" | "="): boolean;
    parseJSXIdentifier(): JSXNode.JSXIdentifier;
    parseJSXElementName(): JSXNode.JSXElementName;
    parseJSXAttributeName(): JSXNode.JSXAttributeName;
    parseJSXStringLiteralAttribute(): Node.Literal;
    parseJSXExpressionAttribute(): JSXNode.JSXExpressionContainer;
    parseJSXAttributeValue(): JSXNode.JSXAttributeValue;
    parseJSXNameValueAttribute(): JSXNode.JSXAttribute;
    parseJSXSpreadAttribute(): JSXNode.JSXSpreadAttribute;
    parseJSXAttributes(): JSXNode.JSXElementAttribute[];
    parseJSXOpeningElement(): JSXNode.JSXOpeningElement;
    parseJSXBoundaryElement(): JSXNode.JSXOpeningElement | JSXNode.JSXClosingElement;
    parseJSXEmptyExpression(): JSXNode.JSXEmptyExpression;
    parseJSXExpressionContainer(): JSXNode.JSXExpressionContainer;
    parseJSXChildren(): JSXNode.JSXChild[];
    parseComplexJSXElement(el: MetaJSXElement): MetaJSXElement;
    parseJSXElement(): JSXNode.JSXElement;
    parseJSXRoot(): JSXNode.JSXElement;
}
export {};
