import { ErrorHandler } from './error-handler';
import { RawToken } from './token';
export interface Position {
    line: number;
    column: number;
}
export interface SourceLocation {
    start: Position;
    end: Partial<Position>;
    source?: string;
}
export interface Comment {
    multiLine: boolean;
    slice: number[];
    range: [number, number];
    loc: SourceLocation;
}
interface ScannerState {
    index: number;
    lineNumber: number;
    lineStart: number;
}
export declare class Scanner {
    readonly source: string;
    readonly errorHandler: ErrorHandler;
    trackComment: boolean;
    isModule: boolean;
    index: number;
    lineNumber: number;
    lineStart: number;
    curlyStack: ('{' | '${')[];
    private readonly length;
    constructor(code: string, handler: ErrorHandler);
    saveState(): ScannerState;
    restoreState(state: ScannerState): void;
    eof(): boolean;
    throwUnexpectedToken(message?: string): never;
    tolerateUnexpectedToken(message?: string): void;
    skipSingleLineComment(offset: number): Comment[];
    skipMultiLineComment(): Comment[];
    scanComments(): Comment[];
    isFutureReservedWord(id: string): boolean;
    isStrictModeReservedWord(id: string): boolean;
    isRestrictedWord(id: string): boolean;
    isKeyword(id: string): boolean;
    codePointAt(i: number): number;
    scanHexEscape(prefix: string): string | null;
    scanUnicodeCodePointEscape(): string;
    getIdentifier(): string;
    getComplexIdentifier(): string;
    octalToDecimal(ch: string): {
        code: number;
        octal: boolean;
    };
    scanIdentifier(): RawToken;
    scanPunctuator(): RawToken;
    scanHexLiteral(start: number): RawToken;
    scanBinaryLiteral(start: number): RawToken;
    scanOctalLiteral(prefix: string, start: number): RawToken;
    isImplicitOctalLiteral(): boolean;
    scanNumericLiteral(): RawToken;
    scanStringLiteral(): RawToken;
    scanTemplate(): RawToken;
    testRegExp(pattern: string, flags: string): RegExp | null;
    scanRegExpBody(): string;
    scanRegExpFlags(): string;
    scanRegExp(): RawToken;
    lex(): RawToken;
}
export {};
