import { IRegExpFlags } from './IRegExpFlags';
import { SourceLocation } from './scanner';
export declare const enum Token {
    BooleanLiteral = 1,
    EOF = 2,
    Identifier = 3,
    Keyword = 4,
    NullLiteral = 5,
    NumericLiteral = 6,
    Punctuator = 7,
    StringLiteral = 8,
    RegularExpression = 9,
    Template = 10,
    JSXIdentifier = 11,
    JSXText = 12
}
/**
 * A string may be a bit imprecise, but we also have to allow for identifiers.
 * A possibility may be to split the value into two fields?
 * The scanner puts numbers in this type.
 */
export type RawTokenValue = string | number | null;
/**
 * Raw tokens are produced by the scanner.ts
 */
export interface RawToken {
    type: Token;
    value: RawTokenValue;
    pattern?: string;
    flags?: string;
    regex?: RegExp | null;
    octal?: boolean;
    cooked?: string;
    head?: boolean;
    tail?: boolean;
    lineNumber: number;
    lineStart: number;
    start: number;
    end: number;
}
export declare const TokenName: {
    [token: number]: string;
};
/**
 * RawToken is converted into TokenEntry by the parser.ts convertToken() function.
 * Hence, this could be called a ParserToken.
 */
export interface TokenEntry {
    type?: string | number | 'BlockComment' | 'LineComment';
    value?: number | string;
    lineNumber?: number;
    lineStart?: number;
    literal?: IRegExpFlags;
    octal?: boolean;
    regex?: {
        pattern: string;
        flags: string;
    };
    start?: number;
    startLineNumber?: number;
    startLineStart?: number;
    end?: number;
    loc?: SourceLocation;
    range?: [number, number];
}
